==> org.apache.sling.models.impl-1.4.8-source-release.zip: org.apache.sling.models.impl-1.4.8/src/main/java/org/apache/sling/models/impl/via/ForcedResourceTypeViaProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.impl.via;

import javax.annotation.Nonnull;

import org.apache.commons.lang3.StringUtils;
import org.apache.felix.scr.annotations.Component;
import org.apache.felix.scr.annotations.Service;
import org.apache.sling.api.resource.Resource;
import org.apache.sling.models.annotations.ViaProviderType;
import org.apache.sling.models.annotations.via.ForcedResourceType;

@Component
@Service
public class ForcedResourceTypeViaProvider extends AbstractResourceTypeViaProvider {
    @Override
    public Class<? extends ViaProviderType> getType() {
        return ForcedResourceType.class;
    }

    @Override
    protected String getResourceType(@Nonnull Resource resource, @Nonnull String value) {
        return value;
    }

    @Override
    protected boolean handle(@Nonnull String value) {
        return StringUtils.isNotBlank(value);
    }
}

==> org.apache.sling.models.impl-1.6.0-source-release.zip: org.apache.sling.models.impl-1.6.0/src/main/java/org/apache/sling/models/impl/via/ForcedResourceTypeViaProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.impl.via;

import org.apache.commons.lang3.StringUtils;
import org.apache.sling.api.resource.Resource;
import org.apache.sling.models.annotations.ViaProviderType;
import org.apache.sling.models.annotations.via.ForcedResourceType;
import org.apache.sling.models.spi.ViaProvider;
import org.jetbrains.annotations.NotNull;
import org.osgi.service.component.annotations.Component;

@Component(service=ViaProvider.class)
public class ForcedResourceTypeViaProvider extends AbstractResourceTypeViaProvider {
    @Override
    public Class<? extends ViaProviderType> getType() {
        return ForcedResourceType.class;
    }

    @Override
    protected String getResourceType(@NotNull Resource resource, @NotNull String value) {
        return value;
    }

    @Override
    protected boolean handle(@NotNull String value) {
        return StringUtils.isNotBlank(value);
    }
}
